"""
Small script to connect to a Reven server from a scenario name and the project manager,
spawning the server if necessary.

Prerequisites:
    - reven2
    - Ipython (for command-line invocation)

Usage (command-line invocation):
    python connect.py --url http://project-manager-url:8880 --name scenario_name

    This will spawn a new IPython interactive session where the "server" variable is set to a RevenServer connected to
    the "scenario_name" scenario.

    If a new reven server had to be spawned, it is destroyed when leaving the IPython shell.
"""

import argparse

import reven2
import reven2.preview.project_manager as project_manager


def get_header(server):
    return """[+] Connected to server on {host}:{port}.
[+] Use the 'server' variable to access the server.
[+] Set 'connection.ephemeral = False' to keep the server open after leaving the session

>>> server.trace.transition_count
{transition_count}
""".format(
        host=server.host, port=server.port, transition_count=server.trace.transition_count
    )


if __name__ == "__main__":
    import IPython
    from traitlets.config.loader import Config

    parser = argparse.ArgumentParser(description="Connect to a scenario from its name")
    parser.add_argument("--url", required=True, help="The URL of the Reven project manager")
    parser.add_argument("--name", required=True, help="Name of the scenario to connect to")

    args = parser.parse_args()

    pm = project_manager.ProjectManager(args.url)
    connection = pm.connect(args.name)
    with connection as server:
        # start IPython
        user_ns = {"connection": connection, "server": server, "reven2": reven2}
        c = Config()
        c.TerminalInteractiveShell.banner2 = get_header(server)
        IPython.start_ipython(argv=[], user_ns=user_ns, config=c)
