from . import colors


def get_color_resource_status(status):
    if status == "PENDING":
        return colors.WARN
    elif status == "REPLAYING":
        return colors.BLUE
    elif status == "COMPATIBLE" or status == "READY":
        return colors.OK
    elif status == "NOT_COMPATIBLE" or status == "REPLAY_FAILED":
        return colors.ERR
    return ""


def display_resources_progress(resources):
    print("Resources:")
    # pretty print resources state
    for resource in resources:
        color = get_color_resource_status(resource["status"])
        print(
            "{} {:<18s} {:<18s} {:<18s} {:<18s} {}".format(
                color,
                resource["display_name"],
                resource["progress"],
                resource["natural_size"],
                resource["display_status"],
                colors.ENDC,
            )
        )


def display_failed_resources_log(project_manager, resources):
    # retrieve replay log from task(s) that failed
    for resource in resources:
        if resource["status"] == "REPLAY_FAILED" and resource["replay_task"]:
            # retrieve main (default) log and display it
            task_log = project_manager.get_task_log(resource["replay_task"]["id"])
            print(resource["display_name"])
            print("Main log")
            print(task_log)
            print("---------------")
            # retrieve replay log and display it
            replay_task_log = project_manager.get_task_log(resource["replay_task"]["id"], name="replay")
            print("Replay log")
            print(replay_task_log)
            print("---------------")


def get_color_action_status(status):
    if status == "PENDING":
        return colors.WARN
    elif status == "RUNNING":
        return colors.BLUE
    elif status == "SUCCESS":
        return colors.OK
    elif status == "FAILURE":
        return colors.ERR
    # if `NOT_RAN`, no color
    return ""


def display_actions_progress(actions):
    print("Actions:")
    # pretty print actions state
    for action in actions:
        color = get_color_action_status(action["status"])
        print("{} {:<24s} {:<18s} {}".format(color, action["display_name"], action["display_status"], colors.ENDC))


def display_failed_actions_log(project_manager, actions):
    for action in actions:
        if action["status"] == "FAILURE" and action["replay_task"]:
            # retrieve log and display it
            task_log = project_manager.get_task_log(action["replay_task"]["id"])
            print(action["display_name"])
            print("Main log")
            print(task_log)
            print("---------------")


####################################################
# UTILS FUNCTIONS USED IN PROJECT MANAGER EXAMPLES #
####################################################


def display_resources_actions_progress(resources, actions):
    display_resources_progress(resources)
    print()
    display_actions_progress(actions)
    print()


def display_failed_resources_actions_log(project_manager, resources, actions):
    display_failed_resources_log(project_manager, resources)
    print()
    display_failed_actions_log(project_manager, actions)
    print()


def is_replay_finished(scenario):
    return scenario["replay"]["status"] not in [
        "RUNNING",
        "PENDING",
        "NOT_RAN",
    ]
